jactorch.quickstart.models
==========================

.. automodule:: jactorch.quickstart.models

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      LinearClassificationModel
      LinearRegressionModel
      MLPClassificationModel
      MLPModel
      MLPRegressionModel
      ModelIOKeysMixin
   
   

   
   
   

   
   
   








.. rubric:: Class LinearClassificationModel
.. autoclass:: LinearClassificationModel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class LinearRegressionModel
.. autoclass:: LinearRegressionModel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MLPClassificationModel
.. autoclass:: MLPClassificationModel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MLPModel
.. autoclass:: MLPModel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MLPRegressionModel
.. autoclass:: MLPRegressionModel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ModelIOKeysMixin
.. autoclass:: ModelIOKeysMixin
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







